"use strict";

exports.__esModule = true;
exports["default"] = exports.useLocalStorage = void 0;

var _react = require("react");

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

var setItem = function setItem(key, value) {
  if (!['string'].includes(typeof value)) {
    localStorage.setItem(key, JSON.stringify(value));
  } else {
    localStorage.setItem(key, value);
  }
};

var getItem = function getItem(key) {
  var item = localStorage.getItem(key);

  try {
    return JSON.parse(item);
  } catch (error) {
    return item;
  }
};

var useLocalStorage = function useLocalStorage(key, defaultValue) {
  var _useState = (0, _react.useState)(function () {
    var item = getItem(key);

    if (item) {
      return item;
    } else {
      setItem(key, defaultValue);
      return defaultValue;
    }
  }),
      state = _useState[0],
      setState = _useState[1];

  var setValue = function setValue(value) {
    if (typeof value === 'object' && typeof state === 'object') {
      setState(_extends({}, state, {}, value));
      setItem(key, _extends({}, state, {}, value));
    } else {
      setState(value);
      setItem(key, value);
    }
  };

  var localStorageChanged = function localStorageChanged(e) {
    if (e.key === key) {
      var value;

      try {
        value = JSON.parse(e.newValue);
      } catch (e) {
        value = e.newValue;
      }

      var newValue;

      if (typeof value === 'object' && typeof state === 'object') {
        newValue = _extends({}, state, {}, value);
      } else {
        newValue = value;
      }

      setState(newValue);
    }
  };

  (0, _react.useEffect)(function () {
    window.addEventListener('storage', localStorageChanged);
    return function () {
      window.removeEventListener('storage', localStorageChanged);
    };
  });
  (0, _react.useEffect)(function () {
    setState(getItem(key));
  }, [key]);
  return [state, setValue];
};

exports.useLocalStorage = useLocalStorage;
var _default = useLocalStorage;
exports["default"] = _default;