"use strict";

exports.__esModule = true;
exports.mgiGene = exports.clinGenCondition = exports.clinGenHGNCGene = exports.alamutEntry = exports.orphanetEntry = exports.hpoEntry = exports.omimSearch = exports.omimEntry = exports.hgmdGene = exports.hgmdVariant = exports.decipherRegionSearch = exports.decipherVariant = exports.gnomadGeneEntry = exports.exacGeneEntry = exports.gtexEntry = exports.geneReviewsEntry = exports.hgncEntry = exports.ghrEntry = exports.geneCardsEntry = exports.dgvRegionSearch = exports.ucscLocus = exports.gnomadVariant = exports.exacVariant = exports.ensemblLocus = exports.cosmicEntry = exports.clinvarEntry = exports.clinvarSearch = exports.variationViewer = exports.pubmedGene = exports.pubmedEntry = exports.pubmedSearch = exports.esearch = exports.esummary = exports.efetch = void 0;

var _lodash = require("lodash");

var urls = _interopRequireWildcard(require("../constants/genomics-urls"));

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function _getRequireWildcardCache() { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { "default": obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj["default"] = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

// NCBI APIs
var efetch = function efetch(db, id, retmode, params) {
  if (retmode === void 0) {
    retmode = 'xml';
  }

  if (params === void 0) {
    params = '';
  }

  return urls.NCBI_EFETCH_ENDPOINT + "?retmode=" + retmode + "&db=" + db + "&id=" + id + "&" + params;
};

exports.efetch = efetch;

var esummary = function esummary(db, id, retmode, params) {
  if (retmode === void 0) {
    retmode = 'json';
  }

  if (params === void 0) {
    params = '';
  }

  return urls.NCBI_ESUMMARY_ENDPOINT + "?retmode=" + retmode + "&db=" + db + "&id=" + id + "&" + params;
};

exports.esummary = esummary;

var esearch = function esearch(db, term, retmode, params) {
  if (retmode === void 0) {
    retmode = 'json';
  }

  if (params === void 0) {
    params = '';
  }

  return urls.NCBI_ESEARCH_ENDPOINT + "?retmode=" + retmode + "&db=" + db + "&term=" + term + "&" + params;
}; // NCBI URLs


exports.esearch = esearch;

var pubmedSearch = function pubmedSearch(term) {
  return urls.PUBMED_URL + "/?term=" + term;
};

exports.pubmedSearch = pubmedSearch;

var pubmedEntry = function pubmedEntry(pmid) {
  return urls.PUBMED_URL + "/" + pmid;
};

exports.pubmedEntry = pubmedEntry;

var pubmedGene = function pubmedGene(gene) {
  return urls.NCBI_GENE_URL + "/?term=" + gene;
};

exports.pubmedGene = pubmedGene;

var variationViewer = function variationViewer(chr, start, end, assembly) {
  if (assembly === void 0) {
    assembly = 'GCF_000001405.25';
  }

  return urls.NCBI_VARIATION_URL + "/?assm=" + assembly + "&chr=" + chr + "&from=" + start + "&to=" + end;
};

exports.variationViewer = variationViewer;

var clinvarSearch = function clinvarSearch(term) {
  return urls.CLINVAR_URL + "/?term=" + term;
};

exports.clinvarSearch = clinvarSearch;

var clinvarEntry = function clinvarEntry(id) {
  return urls.CLINVAR_URL + "/variation/" + id;
}; // Genomic URLs


exports.clinvarEntry = clinvarEntry;

var cosmicEntry = function cosmicEntry(id) {
  var trimmedId = (0, _lodash.trimStart)(id, 'COSM');
  return urls.COSMIC_URL + "/mutation/overview?id=" + trimmedId;
};

exports.cosmicEntry = cosmicEntry;

var ensemblLocus = function ensemblLocus(chr, start, end, genome, species) {
  if (genome === void 0) {
    genome = 'grch37';
  }

  if (species === void 0) {
    species = 'Homo_sapiens';
  }

  var url; // TODO: This should be switched to a lookup object sicne genome and species are so related

  if (['hg19', 'grch37'].includes((0, _lodash.toLower)(genome))) {
    url = "" + urls.ENSEMBL_GRCH37_URL;
  } else if (['hg38', 'grch38'].includes((0, _lodash.toLower)(genome))) {
    url = "" + urls.ENSEMBL_GRCH38_URL;
  } else {
    throw new Error("genome: " + genome + " not supported!");
  }

  return url + "/" + species + "/Location/View?db=core;r=" + chr + ":" + start + "-" + end;
};

exports.ensemblLocus = ensemblLocus;

var exacVariant = function exacVariant(chr, pos, ref, alt) {
  return urls.EXAC_URL + "/variant/" + chr + "-" + pos + "-" + ref + "-" + alt;
};

exports.exacVariant = exacVariant;

var gnomadVariant = function gnomadVariant(chr, pos, ref, alt) {
  return urls.GNOMAD_URL + "/variant/" + chr + "-" + pos + "-" + ref + "-" + alt;
};

exports.gnomadVariant = gnomadVariant;

var ucscLocus = function ucscLocus(chr, start, end, genome) {
  if (genome === void 0) {
    genome = 'hg19';
  }

  return urls.UCSC_URL + "/cgi-bin/hgTracks?db=" + genome + "&position=chr" + chr + ":" + start + "-" + end;
};

exports.ucscLocus = ucscLocus;

var dgvRegionSearch = function dgvRegionSearch(chr, start, end) {
  return urls.DGV_URL + "/gb2/gbrowse/dgv2_hg19/?name=chr" + chr + ":" + start + "-" + end + ";search=Search";
}; // Gene Resources


exports.dgvRegionSearch = dgvRegionSearch;

var geneCardsEntry = function geneCardsEntry(gene) {
  return urls.GENE_CARDS_URL + "/cgi-bin/carddisp.pl?gene=" + gene;
};

exports.geneCardsEntry = geneCardsEntry;

var ghrEntry = function ghrEntry(gene) {
  return urls.GHR_URL + "/gene/" + gene;
};

exports.ghrEntry = ghrEntry;

var hgncEntry = function hgncEntry(gene) {
  return urls.HGNC_URL + "/cgi-bin/search?search_type=all&search=" + gene;
};

exports.hgncEntry = hgncEntry;

var geneReviewsEntry = function geneReviewsEntry(gene) {
  return urls.GENEREVIEWS_URL + "/?term=" + gene;
};

exports.geneReviewsEntry = geneReviewsEntry;

var gtexEntry = function gtexEntry(gene) {
  return urls.GTEX_URL + "/home/gene/" + gene;
};

exports.gtexEntry = gtexEntry;

var exacGeneEntry = function exacGeneEntry(gene) {
  return urls.EXAC_URL + "/gene/" + gene;
};

exports.exacGeneEntry = exacGeneEntry;

var gnomadGeneEntry = function gnomadGeneEntry(gene) {
  return urls.GNOMAD_URL + "/gene/" + gene;
}; // Clinical Resources


exports.gnomadGeneEntry = gnomadGeneEntry;

var decipherVariant = function decipherVariant(chr, start, end) {
  return urls.DECIPHER_URL + "/search?q=" + chr + ":" + start + "-" + end + "#consented-patients/results";
};

exports.decipherVariant = decipherVariant;

var decipherRegionSearch = function decipherRegionSearch(chr, start, end) {
  return urls.DECIPHER_URL + "/search?q=chr" + chr + ":" + start + "-" + end + "#consented-patients/results";
};

exports.decipherRegionSearch = decipherRegionSearch;

var hgmdVariant = function hgmdVariant(cdna) {
  return urls.HGMD_URL + "/hgmd/pro/mut.php?acc=" + cdna;
};

exports.hgmdVariant = hgmdVariant;

var hgmdGene = function hgmdGene(gene) {
  return urls.HGMD_URL + "/hgmd/pro/gene.php?gene=" + gene;
};

exports.hgmdGene = hgmdGene;

var omimEntry = function omimEntry(id) {
  return urls.OMIM_URL + "/entry/" + id;
};

exports.omimEntry = omimEntry;

var omimSearch = function omimSearch(term) {
  return urls.OMIM_URL + "/search/?index=entry&search=" + term;
}; // Phenotype Resources


exports.omimSearch = omimSearch;

var hpoEntry = function hpoEntry(id) {
  if ((0, _lodash.startsWith)(id, 'HP:')) {
    return urls.HPO_URL + "/hpoweb/showterm?id=" + id;
  } else {
    var hpoId = (0, _lodash.padStart)(id, 7, '0');
    return urls.HPO_URL + "/hpoweb/showterm?id=HP:" + hpoId;
  }
};

exports.hpoEntry = hpoEntry;

var orphanetEntry = function orphanetEntry(id) {
  return urls.ORPHANET_URL + "/consor/cgi-bin/OC_Exp.php?Lng=EN&Expert=" + id;
}; // Internal Resources


exports.orphanetEntry = orphanetEntry;

var alamutEntry = function alamutEntry(cdna) {
  return urls.ALAMUT_URL + "/show?request=" + cdna;
}; // ClinGen urls


exports.alamutEntry = alamutEntry;

var clinGenHGNCGene = function clinGenHGNCGene(hgncId) {
  return urls.CLINGEN_URL + "/genes/HGNC:" + hgncId;
};

exports.clinGenHGNCGene = clinGenHGNCGene;

var clinGenCondition = function clinGenCondition(mondoId) {
  return urls.CLINGEN_URL + "/conditions/MONDO_" + mondoId;
}; // Mouse Genome DB urls


exports.clinGenCondition = clinGenCondition;

var mgiGene = function mgiGene(geneSymbol) {
  return urls.MGI_URL + "/searchtool/Search.do?query=" + geneSymbol;
};

exports.mgiGene = mgiGene;